@@ -18,16 +18,11 @@ class CMSSatchmoProductPlugin(CMSPluginBase):
 	name = _('Product detail')
 	render_template = 'cmsplugin_satchmo/product.html'
 	raw_id_fields = ('product',)
-	fields = ['product', 'title', 'product_url_path', 'style',]
+	fields = ['product', 'title', 'style',]
 
 	def render(self, context, instance, placeholder):
-		if not hasattr(instance.product, 'site') or instance.product.site == Site.objects.get_current():
-			site_url = ''
-		else:
-			site_url = '//%s' % instance.product.site.domain
 
 		context.update({
-			'site_url': site_url,
 			'instance': instance,
 			'placeholder': placeholder,
 		})
@@ -41,14 +36,9 @@ class CMSSatchmoProductsListingPlugin(CMSPluginBase):
 	model = SatchmoProductsListPlugin
 	name = _('Products listing')
 	render_template = 'cmsplugin_satchmo/products_listing.html'
-	fields = ['list_type', 'number', 'site', 'product_url_path', 'style',]
+	fields = ['list_type', 'number', 'site', 'title', 'style',]
 
 	def render(self, context, instance, placeholder):
-		if not hasattr(instance, 'site') or instance.site == Site.objects.get_current():
-			site_url = ''
-		else:
-			site_url = '//%s' % instance.site.domain
-
 		products = Product.objects.active().filter(site=instance.site)
 
 		if instance.list_type == RECENT_PRODUCTS_CHOICE_ID:
@@ -61,10 +51,11 @@ class CMSSatchmoProductsListingPlugin(CMSPluginBase):
 			raise ValueError('(cmsplugin_satchmo) List type is not defined in PRODUCTS_LISTING_CHOICES!')
 
 		products = products[:instance.number]
+		for product in products:
+			product.get_absolute_url = instance.create_absolute_url(product)
 
 		context.update({
 			'products': products,
-			'site_url': site_url,
 			'instance': instance,
 			'placeholder': placeholder,
 		})
@@ -80,24 +71,12 @@ class CMSSatchmoCategoryPlugin(CMSPluginBase):
 	name = _('Category detail')
 	render_template = 'cmsplugin_satchmo/category.html'
 	raw_id_fields = ('category',)
-	fields = ['category', 'title', 'category_url_path', 'style',]
+	fields = ['category', 'title', 'style',]
 
 	def render(self, context, instance, placeholder):
-		if not hasattr(instance.category, 'site') or instance.category.site == Site.objects.get_current():
-			site_url = ''
-		else:
-			site_url = '//%s' % instance.category.site.domain
-
 		category = Category.objects.get(id=instance.category_id)
-		slug_list = [cat.slug for cat in category.parents()]
-		if slug_list:
-			slug_list = "/".join(slug_list) + "/"
-		else:
-			slug_list = ""
 
 		context.update({
-			'site_url': site_url,
-			'parent_slugs': slug_list,
 			'instance': instance,
 			'placeholder': placeholder,
 		})
@@ -112,28 +91,21 @@ class CMSSatchmoCategoriesListPlugin(CMSPluginBase):
 	model = SatchmoCategoriesListPlugin
 	name = _('Categories listing')
 	render_template = 'cmsplugin_satchmo/categories_listing.html'
-	fields = ['main_category', 'site', 'category_url_path', 'style',]
+	fields = ['main_category', 'site', 'title', 'style',]
 
 	def render(self, context, instance, placeholder):
-		if not hasattr(instance, 'site') or instance.site == Site.objects.get_current():
-			site_url = ''
-		else:
-			site_url = '//%s' % instance.site.domain
-
 		categories = Category.objects.active().filter(site=instance.site)
 
 		if instance.main_category:
 			categories = categories.filter(parent=instance.main_category)
-			slug_list = [cat.slug for cat in instance.main_category.parents()]
-			slug_list = "/".join(slug_list) + "/"
-		else:
-			categories = categories.filter(parent=None)
-			slug_list = ""
+		
+		categories = categories.order_by('ordering')
 
+		for category in categories:
+			category.get_absolute_url = instance.create_absolute_url(category)
+			
 		context.update({
-			'categories': categories.order_by('ordering'),
-			'site_url': site_url,
-			'parent_slugs': slug_list,
+			'categories': categories,
 			'instance': instance,
 			'placeholder': placeholder,
 		})
